using System;
using System.Drawing;
using System.Drawing.Imaging;
using System.Drawing.Printing;
using System.Windows.Forms;

using SoftwareFX.ChartFX.Lite;
using SoftwareFX.ChartFX.Lite.Base;

using hsc.system;

namespace hsc.chart
{
	/// <summary>
	/// Listens for events fired from chart dialog controls and
	/// takes appropriate action.
	/// </summary>
	public class ChartDialogListener
	{
		private Form dialog;
		private Chart chart;

		private PrintDocument printDocument;

		/// <summary>
		/// Creates a new ChartDialogListener with the specified chart.
		/// </summary>
		/// <param name="f">The chart dialog.</param>
		/// <param name="c">The listener's associated chart.</param>
		public ChartDialogListener( Form f, Chart c )
		{
			dialog = f;
			chart = c;

			printDocument = new PrintDocument();
			printDocument.PrintPage += new PrintPageEventHandler( printChartPage );
		}

		/// <summary>
		/// Called when the close menu item is clicked.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		public void closeItemClicked( Object source, EventArgs e )
		{
			dialog.Close();
		}

		/// <summary>
		/// Called when the page setup item is clicked.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		public void pageSetupItemClicked( Object source, EventArgs e )
		{
			PageSetupDialog setupDialog = new PageSetupDialog();
			setupDialog.Document = printDocument;

			setupDialog.ShowDialog( dialog );
		}

		/// <summary>
		/// Called when the print item is clicked.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		public void printItemClicked( Object source, EventArgs e )
		{
			PrintDialog printDialog = new PrintDialog();
			printDialog.Document = printDocument;
			printDialog.AllowPrintToFile = false;

			DialogResult retVal = printDialog.ShowDialog( dialog );

            if ( retVal == DialogResult.OK )
            {
                printDocument.Print();
            }
		}

		/// <summary>
		/// Called when the save chart as image menu item is clicked.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		public void saveImageItemClicked( Object source, EventArgs e )
		{
			Properties props = Properties.Instance;

			SaveFileDialog fileChooser = new SaveFileDialog();
			fileChooser.AddExtension = true;
			fileChooser.Filter =
				"BMP Images (*.bmp)|*.bmp|" +
				"GIF Images (*.gif)|*.gif|" +
				"JPEG Images (*.jpg,*.jpeg)|*.jpg;*.jpeg|" +
				"PNG Images (*.png)|*.png|" +
				"TIFF Images (*.tif,*.tiff)|*.tif;*.tiff";
			fileChooser.FilterIndex = props.getProperty( "lastchartsave.filter", 0 );
			fileChooser.InitialDirectory = props.getProperty( "lastchartsave.dir", "" );
			fileChooser.OverwritePrompt = true;
			fileChooser.Title = "Save Chart As Image";

			fileChooser.ShowDialog( dialog );

			String filePath = fileChooser.FileName;

			if ( !( filePath.Equals( "" ) ) )
			{
				props.setProperty( "lastchartsave.dir", fileChooser.InitialDirectory );
				props.setProperty( "lastchartsave.filter", fileChooser.FilterIndex );

				Bitmap image = new Bitmap( chart.Width, chart.Height );
				chart.Paint( Graphics.FromImage( image ), chart.Bounds, PaintFlags.Background );

				ImageFormat imgFmt = ImageFormat.Bmp;

				if ( fileChooser.FilterIndex == 0 )
				{
					imgFmt = ImageFormat.Bmp;
				}
				else if ( fileChooser.FilterIndex == 1 )
				{
					imgFmt = ImageFormat.Gif;
				}
				else if ( fileChooser.FilterIndex == 2 )
				{
					imgFmt = ImageFormat.Jpeg;
				}
				else if ( fileChooser.FilterIndex == 3 )
				{
					imgFmt = ImageFormat.Png;
				}
				else if ( fileChooser.FilterIndex == 4 )
				{
					imgFmt = ImageFormat.Tiff;
				}

				image.Save( filePath, imgFmt );
			}
		}

		/// <summary>
		/// Called when printing a chart page.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		private void printChartPage( Object source, PrintPageEventArgs e )
		{
			chart.Paint( e.Graphics, e.MarginBounds, PaintFlags.Print );
		}
	}
}
