using System;
using System.Collections;
using System.Drawing;
using System.Resources;
using System.Windows.Forms;
using SoftwareFX.ChartFX.Lite;

using hsc.presentation;
using hsc.system;

namespace hsc.chart
{
	/// <summary>
	/// Generates various types of charts for HSC stats.
	/// </summary>
	public class HSCCharts
	{
		protected static HSCCharts instance = new HSCCharts();

		/// <summary>Gets the system wide instance of HSC Charts.</summary>
		/// <value>An HSCCharts object.</value>
		public static HSCCharts Instance
		{
			get
			{
				return instance;
			}
		}

		/// <summary>
		/// Clients do not instantiate HSCCharts.
		/// </summary>
		protected HSCCharts()
		{
		}

		/// <summary>
		/// Creates a stat chart organized by category.
		/// </summary>
		/// <param name="info">A chart info object describing the desired chart.</param>
		/// <returns>The chart.</returns>
		public Chart createCategorizedChart( OrgChartInfo info )
		{
			Chart chart = new Chart();

			if ( info.GalleryType == Gallery.Pie )
			{
				chart.Gallery = Gallery.Pie;
				chart.LegendBox = false;
				chart.PointLabels = true;
				chart.Titles[0].Text = info.PlayerName + "'s " + info.StatName;
			}
			else
			{
				chart.AxisY.Title.Text = info.StatName;
				chart.Gallery = info.GalleryType;
				chart.LegendBox = false;
				chart.Titles[0].Text = info.PlayerName;
			}

			ICollection catValues = info.CategoryValues;
			int pointIndex = 0;

			if ( info.CategoryName.ToLower().Equals( "date" ) )
			{
				ArrayList dateList = new ArrayList();
				foreach ( String catValue in catValues )
				{
					dateList.Add( DateTime.Parse( catValue ) );
				}

				dateList.Sort();

				catValues = new ArrayList();

				foreach ( DateTime playDate in dateList )
				{
					( (ArrayList)catValues ).Add( playDate.ToShortDateString() );
				}
			}

			chart.OpenData( COD.Values, 1, catValues.Count );

			foreach ( String catValue in catValues )
			{
				chart.Value[0,pointIndex] = info.getStatValue( catValue );
				chart.Legend[pointIndex] = catValue;

				pointIndex += 1;
			}

			if ( chart.AxisY.Max <= 15.0 )
			{
				chart.AxisY.Max = 15.0;
				chart.AxisY.Min = 0.0;
			}

			chart.CloseData( COD.Values );

			return chart;
		}

		/// <summary>
		/// Creates 'other' charts.
		/// </summary>
		/// <param name="info">A chart info object describing the desired chart.</param>
		/// <returns>The chart.</returns>
		public Chart createOtherChart( OtherChartInfo info )
		{
			Chart chart = new Chart();
			chart.Gallery = info.GalleryType;
			chart.Titles[0].Text = info.ChartKind;

			if ( info.ChartKind.ToLower().Equals( "game finishes" ) )
			{
				chart.AxisY.Title.Text = "Games";

				int[] points = info.createFinishesPoints();
				String[] titles = info.getPointTitles();
			
				chart.OpenData( COD.Values, 1, points.Length );

				for ( int i = 0; i < points.Length; i += 1 )
				{
					chart.Value[0,i] = points[i];
					chart.Legend[i] = titles[i];
				}

				chart.CloseData( COD.Values );
			}
			else if ( info.ChartKind.ToLower().Equals( "who's good where?" ) )
			{
				chart.AxisY.Title.Text = "Avg. Score";

				double[][] points = info.createLevelPoints();
				String[] pointTitles = info.getPointTitles();
				String[] seriesTitles = info.getSeriesTitles();

				chart.OpenData( COD.Values, points.Length, points[0].Length );

				for ( int i = 0; i < points.Length; i += 1 )
				{
					for ( int j = 0; j < points[0].Length; j += 1 )
					{
						chart.Value[i,j] = points[i][j];
					}
				}

				for ( int i = 0; i < pointTitles.Length; i += 1 )
				{
					chart.Legend[i] = pointTitles[i];
				}

				for ( int i = 0; i < seriesTitles.Length; i += 1 )
				{
					chart.SerLeg[i] = seriesTitles[i];
				}

				chart.CloseData( COD.Values );
				chart.SerLegBox = true;
			}

			return chart;
		}

		/// <summary>
		/// Creates a single stat chart.
		/// </summary>
		/// <param name="info">A chart info object describing the desired chart.</param>
		/// <returns>The chart.</returns>
		public Chart createSingleStatChart( SingleStatChartInfo info )
		{
			Chart chart = new Chart();

			if ( info.GalleryType == Gallery.Bar )
			{
				chart.AxisY.Title.Text = info.StatName;
				chart.Gallery = Gallery.Bar;
				chart.LegendBox = false;
			}
			else if ( info.GalleryType == Gallery.Pie )
			{
				chart.Gallery = Gallery.Pie;
				chart.LegendBox = true;
				chart.PointLabels = true;
				chart.Titles[0].Text = info.StatName;
			}

			ICollection players = HSCPlayers.Instance.Players;
			int pointIndex = 0;

			chart.OpenData( COD.Values, 1, players.Count );

			foreach ( HSCPlayer player in players )
			{
				chart.Value[0,pointIndex] = info.getStatValue( player );
				chart.Legend[pointIndex] = player.Name;

				pointIndex += 1;
			}

			chart.CloseData( COD.Values );

			return chart;
		}

		/// <summary>
		/// Shows a dialog box containing the given chart.
		/// </summary>
		/// <param name="chart">The chart to show.</param>
		public void showChartDialog( Chart chart )
		{
			ResourceManager resources = new ResourceManager( typeof( HSCForm ) );

			MainMenu chartFormMenu = new MainMenu();
			MenuItem chartMenu = new MenuItem( "Chart" );
			MenuItem saveImageItem = new MenuItem( "Save Chart As Image..." );
			saveImageItem.Shortcut = Shortcut.CtrlS;
			saveImageItem.ShowShortcut = true;
			MenuItem pageSetupItem = new MenuItem( "Page Setup..." );
			MenuItem printItem = new MenuItem( "Print..." );
			printItem.Shortcut = Shortcut.CtrlP;
			printItem.ShowShortcut = true;
			MenuItem closeItem = new MenuItem( "Close" );

			chartFormMenu.MenuItems.Add( chartMenu );
			chartMenu.MenuItems.Add( saveImageItem );
			chartMenu.MenuItems.Add( new MenuItem( "-" ) );
			chartMenu.MenuItems.Add( pageSetupItem );
			chartMenu.MenuItems.Add( printItem );
			chartMenu.MenuItems.Add( new MenuItem( "-" ) );
			chartMenu.MenuItems.Add( closeItem );

			Form chartForm = new Form();
			chartForm.Menu = chartFormMenu;
			chartForm.Icon = (Icon)resources.GetObject( "$this.Icon" );
			chartForm.StartPosition = FormStartPosition.WindowsDefaultLocation;
			chartForm.Size = new Size( 640, 480 );
			chartForm.Text = "HSC Chart";

			ChartDialogListener listener = new ChartDialogListener( chartForm, chart );
			closeItem.Click += new EventHandler( listener.closeItemClicked );
			pageSetupItem.Click += new EventHandler( listener.pageSetupItemClicked );
			printItem.Click += new EventHandler( listener.printItemClicked );
			saveImageItem.Click += new EventHandler( listener.saveImageItemClicked );

			chart.Dock = DockStyle.Fill;
			chartForm.Controls.Add( chart );
			
			chartForm.Show();
		}
	}
}
