using System;
using System.Collections;
using SoftwareFX.ChartFX.Lite;

using hsc.system;

namespace hsc.chart
{
	/// <summary>
	/// Contains information used to generate stat charts
	/// organized by a certain category.
	/// </summary>
	public class OrgChartInfo
	{
		private String categoryName;
		private String chartTypeName;
		private String playerName;
		private String statName;

		/// <summary>Gets or sets the category name.</summary>
		/// <value>A String.</value>
		public String CategoryName
		{
			get
			{
				return categoryName;
			}

			set
			{
				categoryName = value;
			}
		}

		/// <summary>Gets a list of available category values given the player and category name.</summary>
		/// <value>A collection of Strings.</value>
		public ICollection CategoryValues
		{
			get
			{
				HSCPlayer player = HSCPlayers.Instance[playerName];
				ArrayList retVal = new ArrayList();

				foreach ( GameInfo gInfo in player.GameInfos )
				{
					Object catValue = null;

					if ( categoryName.ToLower().Equals( "date" ) )
					{
						catValue = gInfo.PlayDate.ToShortDateString();
					}
					else if ( categoryName.ToLower().Equals( "level" ) )
					{
						catValue = gInfo.Level;
					}
					else if ( categoryName.ToLower().Equals( "playlist" ) )
					{
						catValue = gInfo.PlayList;
					}

					if ( catValue != null && !retVal.Contains( catValue ) )
					{
						retVal.Add( catValue );
					}
				}
				
				retVal.Sort();

				return retVal;
			}
		}

		/// <summary>Gets or sets the chart type name.</summary>
		/// <value>A String.</value>
		public String ChartTypeName
		{
			get
			{
				return chartTypeName;
			}

			set
			{
				chartTypeName = value;
			}
		}

		/// <summary>Gets the gallery chart type.</summary>
		/// <value>A Gallery.</value>
		public Gallery GalleryType
		{
			get
			{
				Gallery retVal = Gallery.Bar;

				if ( chartTypeName.ToLower().Equals( "bar" ) )
				{
					retVal = Gallery.Bar;
				}
				else if ( chartTypeName.ToLower().Equals( "pie" ) )
				{
					retVal = Gallery.Pie;
				}
				else if ( chartTypeName.ToLower().Equals( "area" ) )
				{
					retVal = Gallery.Area;
				}
				else if ( chartTypeName.ToLower().Equals( "line" ) )
				{
					retVal = Gallery.Lines;
				}

				return retVal;
			}
		}

		/// <summary>Gets or sets the player name.</summary>
		/// <value>A String.</value>
		public String PlayerName
		{
			get
			{
				return playerName;
			}

			set
			{
				playerName = value;
			}
		}

		/// <summary>Gets or sets the stat name.</summary>
		/// <value>A string.</value>
		public String StatName
		{
			get
			{
				return statName;
			}

			set
			{
				statName = value;
			}
		}

		/// <summary>
		/// Creates a new OrgChartInfo.
		/// </summary>
		public OrgChartInfo()
		{
		}

		/// <summary>
		/// Gets the stat value for the given category value.
		/// </summary>
		/// <param name="categoryValue">The category value.</param>
		/// <returns>The stat value.</returns>
		public double getStatValue( String categoryValue )
		{
			HSCPlayer player = HSCPlayers.Instance[playerName];
			ArrayList applicableInfoList = new ArrayList();

			foreach ( GameInfo gInfo in player.GameInfos )
			{
				if ( categoryName.ToLower().Equals( "date" ) &&
					categoryValue.Equals( gInfo.PlayDate.ToShortDateString() ) )
				{
					applicableInfoList.Add( gInfo );
				}
				else if ( categoryName.ToLower().Equals( "level" ) &&
					categoryValue.Equals( gInfo.Level ) )
				{
					applicableInfoList.Add( gInfo );
				}
				else if ( categoryName.ToLower().Equals( "playlist" ) &&
					categoryValue.Equals( gInfo.PlayList ) )
				{
					applicableInfoList.Add( gInfo );
				}
			}

			double retVal = 0;

			foreach ( GameInfo gInfo in applicableInfoList )
			{
				if ( statName.ToLower().EndsWith( "assists" ) )
				{
					retVal += gInfo.Assists;
				}
				else if ( statName.ToLower().EndsWith( "deaths" ) )
				{
					retVal += gInfo.Deaths;
				}
				else if ( statName.ToLower().Equals( "games" ) )
				{
					retVal += 1;
				}
				else if ( statName.ToLower().EndsWith( "kills" ) )
				{
					retVal += gInfo.Kills;
				}
				else if ( statName.ToLower().EndsWith( "score" ) )
				{
					retVal += gInfo.Score;
				}
			}

			if ( statName.ToLower().StartsWith( "avg" ) && applicableInfoList.Count != 0 )
			{
				retVal /= applicableInfoList.Count;
			}

			return retVal;
		}
	}
}
