using System;
using System.Drawing;
using System.Windows.Forms;
using SoftwareFX.ChartFX.Lite;

using hsc.chart;
using hsc.system;

namespace hsc.presentation
{
	/// <summary>
	/// Listens for events from controls on the char tab
	/// and takes appropriate action.
	/// </summary>
	public class ChartTabListener
	{
		private bool orgChart3d;
		private String orgChartPlayer;
		private String orgChartCat;
		private String orgChartStat;
		private String orgChartType;

		private bool otherChart3d;
		private String otherChartPlayer;
		private String otherChartKind;

		private bool singleChart3d;
		private String singleChartStat;
		private String singleChartType;

		/// <summary>
		/// Creates a new ChartTabListener.
		/// </summary>
		public ChartTabListener()
		{
	        singleChart3d = false;
			orgChart3d = false;
		}

		/// <summary>
		/// Called when the org 3d check box has been checked or unchecked.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		public void org3dChanged( Object source, EventArgs e )
		{
			CheckBox checkBox = (CheckBox)source;
			orgChart3d = checkBox.Checked;
		}

		/// <summary>
		/// Called when the org chart button has been clicked.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		public void orgButtonClicked( Object source, EventArgs e )
		{
			if ( orgChartPlayer == null || orgChartPlayer.Equals( "" ) )
			{
				return;
			}

			HSCMain.HscForm.Cursor = Cursors.WaitCursor;

			HSCCharts charts = HSCCharts.Instance;

			OrgChartInfo info = new OrgChartInfo();
			info.CategoryName = orgChartCat;
			info.ChartTypeName = orgChartType;
			info.PlayerName = orgChartPlayer;
			info.StatName = orgChartStat;

			Chart chart = charts.createCategorizedChart( info );
			chart.BackColor = Color.FromArgb( 240, 240, 240 );
			chart.Chart3D = orgChart3d;
			charts.showChartDialog( chart );

			HSCMain.HscForm.Cursor = Cursors.Default;
		}

		/// <summary>
		/// Called when the org category has changed.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		public void orgCategoryChanged( Object source, EventArgs e )
		{
			ComboBox comboBox = (ComboBox)source;
			
			if ( comboBox.SelectedItem != null )
			{
				orgChartCat = comboBox.SelectedItem.ToString();
			}
		}

		/// <summary>
		/// Called when the org player has changed.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		public void orgPlayerChanged( Object source, EventArgs e )
		{
			ComboBox comboBox = (ComboBox)source;
			
			if ( comboBox.SelectedItem != null )
			{
				orgChartPlayer = comboBox.SelectedItem.ToString();
			}
		}

		/// <summary>
		/// Called when the org stat value has changed.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		public void orgStatChanged( Object source, EventArgs e )
		{
			ComboBox comboBox = (ComboBox)source;
			
			if ( comboBox.SelectedItem != null )
			{
				orgChartStat = comboBox.SelectedItem.ToString();
			}
		}

		/// <summary>
		/// Called when the org chart type has changed.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		public void orgTypeChanged( Object source, EventArgs e )
		{
			ComboBox comboBox = (ComboBox)source;
			
			if ( comboBox.SelectedItem != null )
			{
				orgChartType = comboBox.SelectedItem.ToString();
			}
		}

		/// <summary>
		/// Called when the other chart 3d checkbox has been checked or unchecked.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		public void other3dChanged( Object source, EventArgs e )
		{
			CheckBox checkBox = (CheckBox)source;
			otherChart3d = checkBox.Checked;
		}

		/// <summary>
		/// Called when the other chart button has been clicked.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		public void otherButtonClicked( Object source, EventArgs e )
		{
			if ( ( otherChartPlayer == null || otherChartPlayer.Equals( "" ) ) &&
				!( otherChartKind.ToLower().Equals( "who's good where?" ) ) )
			{
				return;
			}

			HSCMain.HscForm.Cursor = Cursors.WaitCursor;

			HSCCharts charts = HSCCharts.Instance;

			OtherChartInfo info = new OtherChartInfo();
			info.PlayerName = otherChartPlayer;
			info.ChartKind = otherChartKind;

			Chart chart = charts.createOtherChart( info );
			chart.BackColor = Color.FromArgb( 240, 240, 240 );
			chart.Chart3D = otherChart3d;
			charts.showChartDialog( chart );

			HSCMain.HscForm.Cursor = Cursors.Default;
		}

		/// <summary>
		/// Called when the other chart kind has changed.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		public void otherKindChanged( Object source, EventArgs e )
		{
			ComboBox comboBox = (ComboBox)source;
			
			if ( comboBox.SelectedItem != null )
			{
				otherChartKind = comboBox.SelectedItem.ToString();
			}
		}

		/// <summary>
		/// Called when the other chart player has changed.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		public void otherPlayerChanged( Object source, EventArgs e )
		{
			ComboBox comboBox = (ComboBox)source;
			
			if ( comboBox.SelectedItem != null )
			{
				otherChartPlayer = comboBox.SelectedItem.ToString();
			}
		}

		/// <summary>
		/// Called when a combobox displaying player names is about to display its dropdown.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		public void playerDropDown( Object source, EventArgs e )
		{
			ComboBox comboBox = (ComboBox)source;
			comboBox.Items.Clear();
			
			HSCPlayers players = HSCPlayers.Instance;
			foreach ( HSCPlayer player in players.Players )
			{
				comboBox.Items.Add( player.Name );
			}
		}

		/// <summary>
		/// Called when the chart 3d checkbox has been checked or unchecked.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		public void single3dChanged( Object source, EventArgs e )
		{
			CheckBox checkBox = (CheckBox)source;
			singleChart3d = checkBox.Checked;
		}

		/// <summary>
		/// Called when the single stat chart button has been clicked.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		public void singleButtonClicked( Object source, EventArgs e )
		{
			HSCCharts charts = HSCCharts.Instance;

			HSCMain.HscForm.Cursor = Cursors.WaitCursor;

			SingleStatChartInfo info = new SingleStatChartInfo();
			info.ChartTypeName = singleChartType;
			info.StatName = singleChartStat;
			
			Chart chart = charts.createSingleStatChart( info );
			chart.BackColor = Color.FromArgb( 240, 240, 240 );
			chart.Chart3D = singleChart3d;
			charts.showChartDialog( chart );

			HSCMain.HscForm.Cursor = Cursors.Default;
		}

		/// <summary>
		/// Called when the single chart stat combobox selection has changed.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		public void singleStatChanged( Object source, EventArgs e )
		{
			ComboBox comboBox = (ComboBox)source;
			
			if ( comboBox.SelectedItem != null )
			{
				singleChartStat = comboBox.SelectedItem.ToString();
			}
		}

		/// <summary>
		/// Called when the single chart type combobox selection has changed.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		public void singleTypeChanged( Object source, EventArgs e )
		{
			ComboBox comboBox = (ComboBox)source;
			
			if ( comboBox.SelectedItem != null )
			{
				singleChartType = comboBox.SelectedItem.ToString();
			}
		}
	}
}