using System;
using System.Diagnostics;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Threading;
using System.Windows.Forms;

using hsc.system;

namespace hsc.presentation
{
	/// <summary>
	/// Represents the main UI form for Halo2 Stat Collector.
	/// </summary>
	public class HSCForm : System.Windows.Forms.Form
	{
		#region Windows Form Designer generated state

		private System.Windows.Forms.MenuItem fileMenu;
		private System.Windows.Forms.MenuItem toolsMenu;
		private System.Windows.Forms.MenuItem exitMenuItem;
		private System.Windows.Forms.MenuItem addPlayerMenuItem;
		private System.Windows.Forms.MainMenu hscFormMenu;
		private System.Windows.Forms.StatusBar statusBar;
		private System.Windows.Forms.StatusBarPanel textStatusPanel;
		private System.Windows.Forms.StatusBarPanel progStatusPanel;
		private System.Windows.Forms.MenuItem separatorMenuItem;
		private System.Windows.Forms.MenuItem updateMenuItem;
		private System.Windows.Forms.MenuItem removePlayerMenuItem;
		private System.ComponentModel.IContainer components;
		private System.Windows.Forms.ImageList viewerImageList;
		private System.Windows.Forms.TabControl hscTabPane;
		private System.Windows.Forms.TabPage overviewTab;
		private System.Windows.Forms.ListView ovListView;
		private System.Windows.Forms.TabPage averagesTab;
		private System.Windows.Forms.ListView avgListView;
		private System.Windows.Forms.TabPage viewerTab;
		private System.Windows.Forms.TreeView gameTreeView;
		private System.Windows.Forms.ColumnHeader ovNameHeader;
		private System.Windows.Forms.ColumnHeader ovScoreHeader;
		private System.Windows.Forms.ColumnHeader ovKillsHeader;
		private System.Windows.Forms.ColumnHeader ovDeathsHeader;
		private System.Windows.Forms.ColumnHeader ovAssistsHeader;
		private System.Windows.Forms.ColumnHeader ovGamesHeader;
		private System.Windows.Forms.ColumnHeader ovRoboRankHeader;
		private System.Windows.Forms.ColumnHeader avgNameHeader;
		private System.Windows.Forms.ColumnHeader avgScoreHeader;
		private System.Windows.Forms.ColumnHeader avgPlusMinusHeader;
		private System.Windows.Forms.ColumnHeader avgKillsHeader;
		private System.Windows.Forms.ColumnHeader avgDeathsHeader;
		private System.Windows.Forms.ColumnHeader avgAssistsHeader;
		private System.Windows.Forms.Panel contentPanel;
		private System.Windows.Forms.MenuItem clearStatsItem;
		private System.Windows.Forms.TabPage chartsTab;
		private System.Windows.Forms.GroupBox singleGroupBox;
		private System.Windows.Forms.Button singleChartButton;
		private System.Windows.Forms.ComboBox singleStatComboBox;
		private System.Windows.Forms.Label singleStatLabel;
		private System.Windows.Forms.Label singleTypeLabel;
		private System.Windows.Forms.ComboBox singleTypeComboBox;
		private System.Windows.Forms.GroupBox orgGroupBox;
		private System.Windows.Forms.Label orgPlayerLabel;
		private System.Windows.Forms.Label orgStatLabel;
		private System.Windows.Forms.Label orgCatLabel;
		private System.Windows.Forms.Label orgTypeLabel;
		private System.Windows.Forms.ComboBox orgPlayerComboBox;
		private System.Windows.Forms.ComboBox orgStatComboBox;
		private System.Windows.Forms.ComboBox orgCatComboBox;
		private System.Windows.Forms.ComboBox orgTypeComboBox;
		private System.Windows.Forms.Button orgChartButton;
		private System.Windows.Forms.CheckBox single3dCheckBox;
		private System.Windows.Forms.CheckBox org3dCheckBox;
		private System.Windows.Forms.GroupBox otherGroupBox;
		private System.Windows.Forms.Label otherChartLabel;
		private System.Windows.Forms.Label otherPlayerLabel;
		private System.Windows.Forms.Button otherChartButton;
		private System.Windows.Forms.ComboBox otherPlayerComboBox;
		private System.Windows.Forms.CheckBox other3dCheckBox;
		private System.Windows.Forms.ComboBox otherKindComboBox;
		private System.Windows.Forms.MenuItem saveMenuItem;
		private System.Windows.Forms.MenuItem openMenuItem;
		private System.Windows.Forms.MenuItem separator2MenuItem;

		#endregion

		public delegate int AddNodeDelegate( TreeNode node );

		private StatUpdateThread updateThread;

		/// <summary>Gets or set the menubar enabled state.</summary>
		/// <value>A bool.</value>
		public bool MenuBarEnabled
		{
			get
			{
				return ( fileMenu.Enabled && toolsMenu.Enabled );
			}

			set
			{
				fileMenu.Enabled = value;
				toolsMenu.Enabled = value;
			}
		}

		/// <summary>Gets or sets the status bar text.</summary>
		/// <value>A String.</value>
		public String StatusBarText
		{
			get
			{
				return textStatusPanel.Text;
			}

			set
			{
				textStatusPanel.Text = value;
			}
		}

		/// <summary>
		/// Creates a new HSCForm.
		/// </summary>
		public HSCForm()
		{
			InitializeComponent();

			loadProperties();
			initMenu();
			initCharts();

			updateThread = new StatUpdateThread();

			ovListView.ColumnClick += new ColumnClickEventHandler( listViewColumnClicked );
			avgListView.ColumnClick += new ColumnClickEventHandler( listViewColumnClicked );
			gameTreeView.MouseMove += new MouseEventHandler( treeViewMouseMoved );
			gameTreeView.MouseUp += new MouseEventHandler( treeViewMouseUp );

			this.Closing += new CancelEventHandler( formClosing );
			this.Load += new EventHandler( formLoaded );
		}

		/// <summary>
		/// Updates the view with the current stats.
		/// </summary>
		public void updateView()
		{
			updateOverviewListView();
			updateAveragesListView();
			updateGameTreeView();
		}

		/// <summary>
		/// Causes the form to update the view of HSC players stats.
		/// </summary>
		public void updateStats()
		{
			Thread t = new Thread( updateThread.ThreadStartDelegate );
			t.Start();
		}

		/// <summary>
		/// Called when the form is about to close.
		/// </summary>
		/// <param name="source">The event's source.</param>
		/// <param name="e">The event's data.</param>
		private void formClosing( Object source, CancelEventArgs e )
		{
			Properties props = Properties.Instance;

			if ( this.WindowState == FormWindowState.Normal )
			{
				props.setProperty( "form.location", this.DesktopLocation );
			}

			props.setProperty( "form.windowstate", this.WindowState );
			props.setProperty( "lastarchive.path", HSCPlayers.Instance.CurrentArchivePath );

			props.writeProps();
		}

		/// <summary>
		/// Called before the form is shown for the first time.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		private void formLoaded( Object source, EventArgs e )
		{
			updateStats();
		}

		/// <summary>
		/// Initializes chart controls.
		/// </summary>
		private void initCharts()
		{
			ChartTabListener listener = new ChartTabListener();

			org3dCheckBox.CheckedChanged += new EventHandler( listener.org3dChanged );
			orgCatComboBox.SelectedValueChanged += new EventHandler( listener.orgCategoryChanged );
			orgPlayerComboBox.DropDown += new EventHandler( listener.playerDropDown );
			orgPlayerComboBox.SelectedValueChanged += new EventHandler( listener.orgPlayerChanged );
			orgStatComboBox.SelectedValueChanged += new EventHandler( listener.orgStatChanged );
			orgTypeComboBox.SelectedValueChanged += new EventHandler( listener.orgTypeChanged );
			orgChartButton.Click += new EventHandler( listener.orgButtonClicked );

			other3dCheckBox.CheckedChanged += new EventHandler( listener.other3dChanged );
			otherPlayerComboBox.DropDown += new EventHandler( listener.playerDropDown );
			otherPlayerComboBox.SelectedValueChanged += new EventHandler( listener.otherPlayerChanged );
			otherKindComboBox.SelectedValueChanged += new EventHandler( listener.otherKindChanged );
			otherChartButton.Click += new EventHandler( listener.otherButtonClicked );

			single3dCheckBox.CheckedChanged += new EventHandler( listener.single3dChanged );
			singleStatComboBox.SelectedValueChanged += new EventHandler( listener.singleStatChanged );
			singleTypeComboBox.SelectedValueChanged += new EventHandler( listener.singleTypeChanged );
			singleChartButton.Click += new EventHandler( listener.singleButtonClicked );

			orgCatComboBox.SelectedIndex = 0;
			orgStatComboBox.SelectedIndex = 0;
			orgTypeComboBox.SelectedIndex = 0;
			otherKindComboBox.SelectedIndex = 0;
			singleStatComboBox.SelectedIndex = 0;
			singleTypeComboBox.SelectedIndex = 0;
		}

		/// <summary>
		/// Initializes menu items.
		/// </summary>
		private void initMenu()
		{
			HSCFormMenuListener	menuListener = new HSCFormMenuListener();

			this.addPlayerMenuItem.Click += new EventHandler( menuListener.addPlayerItemClicked );
			this.clearStatsItem.Click += new EventHandler( menuListener.clearStatsItemClicked );
			this.exitMenuItem.Click += new EventHandler( menuListener.exitItemClicked );
			this.openMenuItem.Click += new EventHandler( menuListener.openArchiveItemClicked );
			this.removePlayerMenuItem.Click += new EventHandler( menuListener.removePlayerItemClicked );
			this.saveMenuItem.Click += new EventHandler( menuListener.saveArchiveItemClicked );
			this.updateMenuItem.Click += new EventHandler( menuListener.updateItemClicked );
		}

		/// <summary>
		/// Called when a list view column header is clicked.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The evnet's data.</param>
		private void listViewColumnClicked( Object source, ColumnClickEventArgs e )
		{
			StatComparer sortComparer = null;
			IComparer prevComparer = null;
			int sortDir = StatComparer.SORT_DESCENDING;
			bool ovListViewClicked = source.Equals( ovListView );

			if ( ovListViewClicked )
			{
				prevComparer = ovListView.ListViewItemSorter;
			}
			else
			{
				prevComparer = avgListView.ListViewItemSorter;
			}

			if ( prevComparer != null && prevComparer is StatComparer )
			{
				StatComparer statCompare = (StatComparer)prevComparer;
				if ( statCompare.SortDirection == StatComparer.SORT_DESCENDING &&
					statCompare.SortColumn == e.Column )
				{
					sortDir = StatComparer.SORT_ASCENDING;
				}
			}

			if ( e.Column == 0 )
			{
				sortComparer = new StatComparer( e.Column, sortDir, StatComparer.TYPE_STRING );
			}
			else
			{
				if ( ovListViewClicked )
				{
                    if ( e.Column == 6 )
                    {
                        sortComparer = new StatComparer( e.Column, sortDir, StatComparer.TYPE_FLOAT );
                    }
                    else
                    {
                        sortComparer = new StatComparer( e.Column, sortDir, StatComparer.TYPE_INTEGER );
                    }
				}
				else
				{
					sortComparer = new StatComparer( e.Column, sortDir, StatComparer.TYPE_FLOAT );
				}
			}

			if ( ovListViewClicked )
			{
				ovListView.ListViewItemSorter = sortComparer;
			}
			else
			{
				avgListView.ListViewItemSorter = sortComparer;
			}
		}

		/// <summary>
		/// Loads user properties for this control.
		/// </summary>
		private void loadProperties()
		{
			Properties props = Properties.Instance;

			String windowState = props.getProperty( "form.windowstate", "Normal" );

			if ( windowState.Equals( "Maximized" ) )
			{
				this.WindowState = FormWindowState.Maximized;
			}
			else
			{
				this.WindowState = FormWindowState.Normal;
				this.DesktopLocation =
					(Point)props.getProperty( "form.location", new Point( 100, 100 ) );
			}
		}

		/// <summary>
		/// Called when the mouse is moved over the game tree view.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		private void treeViewMouseMoved( Object source, MouseEventArgs e )
		{
			TreeNode node = gameTreeView.GetNodeAt( new Point( e.X, e.Y ) );

			if ( node != null )
			{
				if ( node.Tag != null && node.Tag.Equals( "viewerNode" ) )
				{
					gameTreeView.Cursor = Cursors.Hand;
				}
				else
				{
					gameTreeView.Cursor = Cursors.Default;
				}
			}
		}

		/// <summary>
		/// Called when the game tree view is clicked.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		private void treeViewMouseUp( Object source, MouseEventArgs e )
		{
			TreeNode node = gameTreeView.GetNodeAt( new Point( e.X, e.Y ) );

			if ( node != null && node.Tag != null && node.Tag.Equals( "viewerNode" ) &&
				e.Button == MouseButtons.Left )
			{
				TreeNode gameNode = node.Parent;
				Process.Start( gameNode.Tag.ToString() );
			}
		}

		/// <summary>
		/// Updates the averages list view.
		/// </summary>
		private void updateAveragesListView()
		{
			avgListView.BeginUpdate();
			avgListView.Items.Clear();

			ICollection players = HSCPlayers.Instance.Players;

			foreach ( HSCPlayer player in players )
			{
				ListViewItem avgItem = new ListViewItem( player.Name );
				avgItem.SubItems.Add( player.AvgScore.ToString( "####0.00" ) );
				avgItem.SubItems.Add( player.AvgPlusMinus.ToString( "+####0.00;-####0.00" ) );
				avgItem.SubItems.Add( player.AvgKills.ToString( "####0.00" ) );
				avgItem.SubItems.Add( player.AvgDeaths.ToString( "####0.00" ) );
				avgItem.SubItems.Add( player.AvgAssists.ToString( "####0.00" ) );

				avgListView.Items.Add( avgItem );
			}

			avgListView.EndUpdate();
		}

		/// <summary>
		/// Updates the game tree view.
		/// </summary>
		private void updateGameTreeView()
		{
			gameTreeView.BeginUpdate();
			gameTreeView.Nodes.Clear();

			ICollection players = HSCPlayers.Instance.Players;

			foreach ( HSCPlayer player in players )
			{
				TreeNode playerNode = new TreeNode( player.Name );
				playerNode.ImageIndex = 0;

				ArrayList gameInfoList = new ArrayList( player.GameInfos );
				gameInfoList.Sort( new GameInfoComparer() );

				foreach ( GameInfo gameInfo in gameInfoList )
				{
					TreeNode gameNode = new TreeNode( gameInfo.Level );
					gameNode.ImageIndex = 1;
					gameNode.SelectedImageIndex = 1;
					gameNode.Tag = gameInfo.GameLink;

					TreeNode playListNode = new TreeNode( "Playlist: " + gameInfo.PlayList );
					playListNode.ImageIndex = 2;
					playListNode.SelectedImageIndex = 2;

					TreeNode playDateNode = new TreeNode( "Date: " + gameInfo.PlayDate.ToString() );
					playDateNode.ImageIndex = 2;
					playDateNode.SelectedImageIndex = 2;

					TreeNode placeNode = new TreeNode( "Finish: " + gameInfo.PlayerPlace );
					placeNode.ImageIndex = 2;
					placeNode.SelectedImageIndex = 2;

					TreeNode viewerNode = new TreeNode( "Launch Game Viewer" );
					viewerNode.ImageIndex = 2;
					viewerNode.SelectedImageIndex = 2;
					viewerNode.NodeFont = new Font( gameTreeView.Font, FontStyle.Underline );
					viewerNode.ForeColor = Color.Blue;
					viewerNode.Tag = "viewerNode";

					gameNode.Nodes.Add( playListNode );
					gameNode.Nodes.Add( playDateNode );
					gameNode.Nodes.Add( placeNode );
					gameNode.Nodes.Add( viewerNode );

					playerNode.Nodes.Add( gameNode );
				}

				gameTreeView.Invoke(
					new AddNodeDelegate( gameTreeView.Nodes.Add ), new object[] { playerNode } );
			}

			gameTreeView.EndUpdate();
		}

		/// <summary>
		/// Updated the overview list view.
		/// </summary>
		private void updateOverviewListView()
		{
			ovListView.BeginUpdate();
			ovListView.Items.Clear();

			ICollection players = HSCPlayers.Instance.Players;

			foreach ( HSCPlayer player in players )
			{
				ListViewItem ovItem = new ListViewItem( player.Name );
				ovItem.SubItems.Add( player.TotalScore.ToString() );
				ovItem.SubItems.Add( player.TotalKills.ToString() );
				ovItem.SubItems.Add( player.TotalDeaths.ToString() );
				ovItem.SubItems.Add( player.TotalAssists.ToString() );
				ovItem.SubItems.Add( player.GameInfos.Count.ToString() );
				ovItem.SubItems.Add( player.RoboRank.ToString( "####0.00" ) );

				ovListView.Items.Add( ovItem );
			}

			ovListView.EndUpdate();
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if ( disposing )
			{
				if ( components != null )
				{
					components.Dispose();
				}
			}

			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.components = new System.ComponentModel.Container();
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(HSCForm));
			this.hscFormMenu = new System.Windows.Forms.MainMenu();
			this.fileMenu = new System.Windows.Forms.MenuItem();
			this.exitMenuItem = new System.Windows.Forms.MenuItem();
			this.toolsMenu = new System.Windows.Forms.MenuItem();
			this.addPlayerMenuItem = new System.Windows.Forms.MenuItem();
			this.removePlayerMenuItem = new System.Windows.Forms.MenuItem();
			this.clearStatsItem = new System.Windows.Forms.MenuItem();
			this.separatorMenuItem = new System.Windows.Forms.MenuItem();
			this.updateMenuItem = new System.Windows.Forms.MenuItem();
			this.viewerImageList = new System.Windows.Forms.ImageList(this.components);
			this.statusBar = new System.Windows.Forms.StatusBar();
			this.textStatusPanel = new System.Windows.Forms.StatusBarPanel();
			this.progStatusPanel = new System.Windows.Forms.StatusBarPanel();
			this.contentPanel = new System.Windows.Forms.Panel();
			this.hscTabPane = new System.Windows.Forms.TabControl();
			this.overviewTab = new System.Windows.Forms.TabPage();
			this.ovListView = new System.Windows.Forms.ListView();
			this.ovNameHeader = new System.Windows.Forms.ColumnHeader();
			this.ovScoreHeader = new System.Windows.Forms.ColumnHeader();
			this.ovKillsHeader = new System.Windows.Forms.ColumnHeader();
			this.ovDeathsHeader = new System.Windows.Forms.ColumnHeader();
			this.ovAssistsHeader = new System.Windows.Forms.ColumnHeader();
			this.ovGamesHeader = new System.Windows.Forms.ColumnHeader();
			this.ovRoboRankHeader = new System.Windows.Forms.ColumnHeader();
			this.averagesTab = new System.Windows.Forms.TabPage();
			this.avgListView = new System.Windows.Forms.ListView();
			this.avgNameHeader = new System.Windows.Forms.ColumnHeader();
			this.avgScoreHeader = new System.Windows.Forms.ColumnHeader();
			this.avgPlusMinusHeader = new System.Windows.Forms.ColumnHeader();
			this.avgKillsHeader = new System.Windows.Forms.ColumnHeader();
			this.avgDeathsHeader = new System.Windows.Forms.ColumnHeader();
			this.avgAssistsHeader = new System.Windows.Forms.ColumnHeader();
			this.viewerTab = new System.Windows.Forms.TabPage();
			this.gameTreeView = new System.Windows.Forms.TreeView();
			this.chartsTab = new System.Windows.Forms.TabPage();
			this.otherGroupBox = new System.Windows.Forms.GroupBox();
			this.otherKindComboBox = new System.Windows.Forms.ComboBox();
			this.otherChartLabel = new System.Windows.Forms.Label();
			this.otherPlayerLabel = new System.Windows.Forms.Label();
			this.otherChartButton = new System.Windows.Forms.Button();
			this.otherPlayerComboBox = new System.Windows.Forms.ComboBox();
			this.other3dCheckBox = new System.Windows.Forms.CheckBox();
			this.orgGroupBox = new System.Windows.Forms.GroupBox();
			this.org3dCheckBox = new System.Windows.Forms.CheckBox();
			this.orgChartButton = new System.Windows.Forms.Button();
			this.orgTypeComboBox = new System.Windows.Forms.ComboBox();
			this.orgCatComboBox = new System.Windows.Forms.ComboBox();
			this.orgStatComboBox = new System.Windows.Forms.ComboBox();
			this.orgPlayerComboBox = new System.Windows.Forms.ComboBox();
			this.orgTypeLabel = new System.Windows.Forms.Label();
			this.orgCatLabel = new System.Windows.Forms.Label();
			this.orgStatLabel = new System.Windows.Forms.Label();
			this.orgPlayerLabel = new System.Windows.Forms.Label();
			this.singleGroupBox = new System.Windows.Forms.GroupBox();
			this.singleTypeComboBox = new System.Windows.Forms.ComboBox();
			this.singleTypeLabel = new System.Windows.Forms.Label();
			this.singleStatLabel = new System.Windows.Forms.Label();
			this.singleChartButton = new System.Windows.Forms.Button();
			this.singleStatComboBox = new System.Windows.Forms.ComboBox();
			this.single3dCheckBox = new System.Windows.Forms.CheckBox();
			this.saveMenuItem = new System.Windows.Forms.MenuItem();
			this.openMenuItem = new System.Windows.Forms.MenuItem();
			this.separator2MenuItem = new System.Windows.Forms.MenuItem();
			((System.ComponentModel.ISupportInitialize)(this.textStatusPanel)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.progStatusPanel)).BeginInit();
			this.contentPanel.SuspendLayout();
			this.hscTabPane.SuspendLayout();
			this.overviewTab.SuspendLayout();
			this.averagesTab.SuspendLayout();
			this.viewerTab.SuspendLayout();
			this.chartsTab.SuspendLayout();
			this.otherGroupBox.SuspendLayout();
			this.orgGroupBox.SuspendLayout();
			this.singleGroupBox.SuspendLayout();
			this.SuspendLayout();
			// 
			// hscFormMenu
			// 
			this.hscFormMenu.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																						this.fileMenu,
																						this.toolsMenu});
			// 
			// fileMenu
			// 
			this.fileMenu.Index = 0;
			this.fileMenu.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					 this.saveMenuItem,
																					 this.openMenuItem,
																					 this.separator2MenuItem,
																					 this.exitMenuItem});
			this.fileMenu.Text = "File";
			// 
			// exitMenuItem
			// 
			this.exitMenuItem.Index = 3;
			this.exitMenuItem.Text = "Exit";
			// 
			// toolsMenu
			// 
			this.toolsMenu.Index = 1;
			this.toolsMenu.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					  this.addPlayerMenuItem,
																					  this.removePlayerMenuItem,
																					  this.clearStatsItem,
																					  this.separatorMenuItem,
																					  this.updateMenuItem});
			this.toolsMenu.Text = "Tools";
			// 
			// addPlayerMenuItem
			// 
			this.addPlayerMenuItem.Index = 0;
			this.addPlayerMenuItem.Shortcut = System.Windows.Forms.Shortcut.CtrlA;
			this.addPlayerMenuItem.Text = "Add Player";
			// 
			// removePlayerMenuItem
			// 
			this.removePlayerMenuItem.Index = 1;
			this.removePlayerMenuItem.Text = "Remove Player(s)";
			// 
			// clearStatsItem
			// 
			this.clearStatsItem.Index = 2;
			this.clearStatsItem.Text = "Clear Player(s) Stats";
			// 
			// separatorMenuItem
			// 
			this.separatorMenuItem.Index = 3;
			this.separatorMenuItem.Text = "-";
			// 
			// updateMenuItem
			// 
			this.updateMenuItem.Index = 4;
			this.updateMenuItem.Shortcut = System.Windows.Forms.Shortcut.F5;
			this.updateMenuItem.Text = "Update Stats Now";
			// 
			// viewerImageList
			// 
			this.viewerImageList.ColorDepth = System.Windows.Forms.ColorDepth.Depth8Bit;
			this.viewerImageList.ImageSize = new System.Drawing.Size(16, 16);
			this.viewerImageList.ImageStream = ((System.Windows.Forms.ImageListStreamer)(resources.GetObject("viewerImageList.ImageStream")));
			this.viewerImageList.TransparentColor = System.Drawing.Color.Transparent;
			// 
			// statusBar
			// 
			this.statusBar.Location = new System.Drawing.Point(0, 251);
			this.statusBar.Name = "statusBar";
			this.statusBar.Panels.AddRange(new System.Windows.Forms.StatusBarPanel[] {
																						 this.textStatusPanel,
																						 this.progStatusPanel});
			this.statusBar.ShowPanels = true;
			this.statusBar.Size = new System.Drawing.Size(448, 22);
			this.statusBar.TabIndex = 1;
			// 
			// textStatusPanel
			// 
			this.textStatusPanel.AutoSize = System.Windows.Forms.StatusBarPanelAutoSize.Spring;
			this.textStatusPanel.Text = "Halo2 Stat Collector";
			this.textStatusPanel.Width = 332;
			// 
			// progStatusPanel
			// 
			this.progStatusPanel.Style = System.Windows.Forms.StatusBarPanelStyle.OwnerDraw;
			// 
			// contentPanel
			// 
			this.contentPanel.Controls.AddRange(new System.Windows.Forms.Control[] {
																					   this.hscTabPane});
			this.contentPanel.Dock = System.Windows.Forms.DockStyle.Fill;
			this.contentPanel.Name = "contentPanel";
			this.contentPanel.Size = new System.Drawing.Size(448, 251);
			this.contentPanel.TabIndex = 2;
			// 
			// hscTabPane
			// 
			this.hscTabPane.Controls.AddRange(new System.Windows.Forms.Control[] {
																					 this.overviewTab,
																					 this.averagesTab,
																					 this.viewerTab,
																					 this.chartsTab});
			this.hscTabPane.Dock = System.Windows.Forms.DockStyle.Fill;
			this.hscTabPane.Name = "hscTabPane";
			this.hscTabPane.SelectedIndex = 0;
			this.hscTabPane.Size = new System.Drawing.Size(448, 251);
			this.hscTabPane.TabIndex = 1;
			// 
			// overviewTab
			// 
			this.overviewTab.Controls.AddRange(new System.Windows.Forms.Control[] {
																					  this.ovListView});
			this.overviewTab.Location = new System.Drawing.Point(4, 22);
			this.overviewTab.Name = "overviewTab";
			this.overviewTab.Size = new System.Drawing.Size(440, 225);
			this.overviewTab.TabIndex = 0;
			this.overviewTab.Text = "Overview";
			// 
			// ovListView
			// 
			this.ovListView.Columns.AddRange(new System.Windows.Forms.ColumnHeader[] {
																						 this.ovNameHeader,
																						 this.ovScoreHeader,
																						 this.ovKillsHeader,
																						 this.ovDeathsHeader,
																						 this.ovAssistsHeader,
																						 this.ovGamesHeader,
                                                                                         this.ovRoboRankHeader });
			this.ovListView.Dock = System.Windows.Forms.DockStyle.Fill;
			this.ovListView.FullRowSelect = true;
			this.ovListView.GridLines = true;
			this.ovListView.LabelWrap = false;
			this.ovListView.MultiSelect = false;
			this.ovListView.Name = "ovListView";
			this.ovListView.Size = new System.Drawing.Size(440, 225);
			this.ovListView.TabIndex = 0;
			this.ovListView.View = System.Windows.Forms.View.Details;
			// 
			// ovNameHeader
			// 
			this.ovNameHeader.Text = "Player Name";
			this.ovNameHeader.Width = 90;
			// 
			// ovScoreHeader
			// 
			this.ovScoreHeader.Text = "Score";
			this.ovScoreHeader.Width = 54;
			// 
			// ovKillsHeader
			// 
			this.ovKillsHeader.Text = "Kills";
			this.ovKillsHeader.Width = 54;
			// 
			// ovDeathsHeader
			// 
			this.ovDeathsHeader.Text = "Deaths";
			this.ovDeathsHeader.Width = 54;
			// 
			// ovAssistsHeader
			// 
			this.ovAssistsHeader.Text = "Assists";
			this.ovAssistsHeader.Width = 54;
			// 
			// ovGamesHeader
			// 
			this.ovGamesHeader.Text = "Games";
			this.ovGamesHeader.Width = 54;
			// 
			// ovRoboRankHeader
			// 
			this.ovRoboRankHeader.Text = "RoboRank" + Char.ConvertFromUtf32( 0x2122 );
			this.ovRoboRankHeader.Width = 75;
			// 
			// averagesTab
			// 
			this.averagesTab.Controls.AddRange(new System.Windows.Forms.Control[] {
																					  this.avgListView});
			this.averagesTab.Location = new System.Drawing.Point(4, 22);
			this.averagesTab.Name = "averagesTab";
			this.averagesTab.Size = new System.Drawing.Size(440, 225);
			this.averagesTab.TabIndex = 1;
			this.averagesTab.Text = "Averages";
			this.averagesTab.Visible = false;
			// 
			// avgListView
			// 
			this.avgListView.AllowColumnReorder = true;
			this.avgListView.Columns.AddRange(new System.Windows.Forms.ColumnHeader[] {
																						  this.avgNameHeader,
																						  this.avgScoreHeader,
																						  this.avgPlusMinusHeader,
																						  this.avgKillsHeader,
																						  this.avgDeathsHeader,
																						  this.avgAssistsHeader});
			this.avgListView.Dock = System.Windows.Forms.DockStyle.Fill;
			this.avgListView.FullRowSelect = true;
			this.avgListView.GridLines = true;
			this.avgListView.LabelWrap = false;
			this.avgListView.MultiSelect = false;
			this.avgListView.Name = "avgListView";
			this.avgListView.Size = new System.Drawing.Size(440, 225);
			this.avgListView.TabIndex = 0;
			this.avgListView.View = System.Windows.Forms.View.Details;
			// 
			// avgNameHeader
			// 
			this.avgNameHeader.Text = "Player Name";
			this.avgNameHeader.Width = 85;
			// 
			// avgScoreHeader
			// 
			this.avgScoreHeader.Text = "Avg. Score";
			this.avgScoreHeader.Width = 70;
			// 
			// avgPlusMinusHeader
			// 
			this.avgPlusMinusHeader.Text = "Avg. +/-";
			this.avgPlusMinusHeader.Width = 70;
			// 
			// avgKillsHeader
			// 
			this.avgKillsHeader.Text = "Kills/Gm";
			this.avgKillsHeader.Width = 70;
			// 
			// avgDeathsHeader
			// 
			this.avgDeathsHeader.Text = "Deaths/Gm";
			this.avgDeathsHeader.Width = 70;
			// 
			// avgAssistsHeader
			// 
			this.avgAssistsHeader.Text = "Assists/Gm";
			this.avgAssistsHeader.Width = 70;
			// 
			// viewerTab
			// 
			this.viewerTab.Controls.AddRange(new System.Windows.Forms.Control[] {
																					this.gameTreeView});
			this.viewerTab.Location = new System.Drawing.Point(4, 22);
			this.viewerTab.Name = "viewerTab";
			this.viewerTab.Size = new System.Drawing.Size(440, 225);
			this.viewerTab.TabIndex = 2;
			this.viewerTab.Text = "Game Viewer";
			this.viewerTab.Visible = false;
			// 
			// gameTreeView
			// 
			this.gameTreeView.Dock = System.Windows.Forms.DockStyle.Fill;
			this.gameTreeView.ImageList = this.viewerImageList;
			this.gameTreeView.ItemHeight = 18;
			this.gameTreeView.Name = "gameTreeView";
			this.gameTreeView.Size = new System.Drawing.Size(440, 225);
			this.gameTreeView.TabIndex = 0;
			// 
			// chartsTab
			// 
			this.chartsTab.Controls.AddRange(new System.Windows.Forms.Control[] {
																					this.otherGroupBox,
																					this.orgGroupBox,
																					this.singleGroupBox});
			this.chartsTab.Location = new System.Drawing.Point(4, 22);
			this.chartsTab.Name = "chartsTab";
			this.chartsTab.Size = new System.Drawing.Size(440, 225);
			this.chartsTab.TabIndex = 3;
			this.chartsTab.Text = "Charts";
			// 
			// otherGroupBox
			// 
			this.otherGroupBox.Controls.AddRange(new System.Windows.Forms.Control[] {
																						this.otherKindComboBox,
																						this.otherChartLabel,
																						this.otherPlayerLabel,
																						this.otherChartButton,
																						this.otherPlayerComboBox,
																						this.other3dCheckBox});
			this.otherGroupBox.Location = new System.Drawing.Point(8, 120);
			this.otherGroupBox.Name = "otherGroupBox";
			this.otherGroupBox.Size = new System.Drawing.Size(208, 112);
			this.otherGroupBox.TabIndex = 2;
			this.otherGroupBox.TabStop = false;
			this.otherGroupBox.Text = "Other Charts";
			// 
			// otherKindComboBox
			// 
			this.otherKindComboBox.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.otherKindComboBox.Items.AddRange(new object[] {
																   "Game Finishes",
																   "Who\'s Good Where?"});
			this.otherKindComboBox.Location = new System.Drawing.Point(80, 48);
			this.otherKindComboBox.Name = "otherKindComboBox";
			this.otherKindComboBox.Size = new System.Drawing.Size(120, 21);
			this.otherKindComboBox.TabIndex = 4;
			// 
			// otherChartLabel
			// 
			this.otherChartLabel.Location = new System.Drawing.Point(8, 48);
			this.otherChartLabel.Name = "otherChartLabel";
			this.otherChartLabel.Size = new System.Drawing.Size(64, 24);
			this.otherChartLabel.TabIndex = 3;
			this.otherChartLabel.Text = "Chart Kind";
			this.otherChartLabel.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// otherPlayerLabel
			// 
			this.otherPlayerLabel.Location = new System.Drawing.Point(8, 24);
			this.otherPlayerLabel.Name = "otherPlayerLabel";
			this.otherPlayerLabel.Size = new System.Drawing.Size(64, 24);
			this.otherPlayerLabel.TabIndex = 2;
			this.otherPlayerLabel.Text = "Player";
			this.otherPlayerLabel.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// otherChartButton
			// 
			this.otherChartButton.Location = new System.Drawing.Point(128, 80);
			this.otherChartButton.Name = "otherChartButton";
			this.otherChartButton.Size = new System.Drawing.Size(72, 24);
			this.otherChartButton.TabIndex = 1;
			this.otherChartButton.Text = "Show Chart";
			// 
			// otherPlayerComboBox
			// 
			this.otherPlayerComboBox.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.otherPlayerComboBox.Location = new System.Drawing.Point(80, 24);
			this.otherPlayerComboBox.Name = "otherPlayerComboBox";
			this.otherPlayerComboBox.Size = new System.Drawing.Size(120, 21);
			this.otherPlayerComboBox.TabIndex = 0;
			// 
			// other3dCheckBox
			// 
			this.other3dCheckBox.Location = new System.Drawing.Point(80, 80);
			this.other3dCheckBox.Name = "other3dCheckBox";
			this.other3dCheckBox.Size = new System.Drawing.Size(40, 24);
			this.other3dCheckBox.TabIndex = 2;
			this.other3dCheckBox.Text = "3D";
			// 
			// orgGroupBox
			// 
			this.orgGroupBox.Controls.AddRange(new System.Windows.Forms.Control[] {
																					  this.org3dCheckBox,
																					  this.orgChartButton,
																					  this.orgTypeComboBox,
																					  this.orgCatComboBox,
																					  this.orgStatComboBox,
																					  this.orgPlayerComboBox,
																					  this.orgTypeLabel,
																					  this.orgCatLabel,
																					  this.orgStatLabel,
																					  this.orgPlayerLabel});
			this.orgGroupBox.Location = new System.Drawing.Point(224, 8);
			this.orgGroupBox.Name = "orgGroupBox";
			this.orgGroupBox.Size = new System.Drawing.Size(208, 224);
			this.orgGroupBox.TabIndex = 1;
			this.orgGroupBox.TabStop = false;
			this.orgGroupBox.Text = "Charts Organized by Category";
			// 
			// org3dCheckBox
			// 
			this.org3dCheckBox.Location = new System.Drawing.Point(80, 128);
			this.org3dCheckBox.Name = "org3dCheckBox";
			this.org3dCheckBox.Size = new System.Drawing.Size(40, 24);
			this.org3dCheckBox.TabIndex = 9;
			this.org3dCheckBox.Text = "3D";
			// 
			// orgChartButton
			// 
			this.orgChartButton.Location = new System.Drawing.Point(128, 128);
			this.orgChartButton.Name = "orgChartButton";
			this.orgChartButton.Size = new System.Drawing.Size(72, 24);
			this.orgChartButton.TabIndex = 8;
			this.orgChartButton.Text = "Show Chart";
			// 
			// orgTypeComboBox
			// 
			this.orgTypeComboBox.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.orgTypeComboBox.Items.AddRange(new object[] {
																 "Bar",
																 "Pie",
																 "Area",
																 "Line"});
			this.orgTypeComboBox.Location = new System.Drawing.Point(96, 96);
			this.orgTypeComboBox.Name = "orgTypeComboBox";
			this.orgTypeComboBox.Size = new System.Drawing.Size(104, 21);
			this.orgTypeComboBox.TabIndex = 7;
			// 
			// orgCatComboBox
			// 
			this.orgCatComboBox.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.orgCatComboBox.Items.AddRange(new object[] {
																"Date",
																"Level",
																"Playlist"});
			this.orgCatComboBox.Location = new System.Drawing.Point(96, 72);
			this.orgCatComboBox.Name = "orgCatComboBox";
			this.orgCatComboBox.Size = new System.Drawing.Size(104, 21);
			this.orgCatComboBox.TabIndex = 6;
			// 
			// orgStatComboBox
			// 
			this.orgStatComboBox.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.orgStatComboBox.Items.AddRange(new object[] {
																 "Score",
																 "Kills",
																 "Deaths",
																 "Assists",
																 "Games",
																 "Avg Score",
																 "Avg Kills",
																 "Avg Deaths",
																 "Avg Assists"});
			this.orgStatComboBox.Location = new System.Drawing.Point(96, 48);
			this.orgStatComboBox.Name = "orgStatComboBox";
			this.orgStatComboBox.Size = new System.Drawing.Size(104, 21);
			this.orgStatComboBox.TabIndex = 5;
			// 
			// orgPlayerComboBox
			// 
			this.orgPlayerComboBox.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.orgPlayerComboBox.Location = new System.Drawing.Point(96, 24);
			this.orgPlayerComboBox.Name = "orgPlayerComboBox";
			this.orgPlayerComboBox.Size = new System.Drawing.Size(104, 21);
			this.orgPlayerComboBox.TabIndex = 4;
			// 
			// orgTypeLabel
			// 
			this.orgTypeLabel.Location = new System.Drawing.Point(8, 96);
			this.orgTypeLabel.Name = "orgTypeLabel";
			this.orgTypeLabel.Size = new System.Drawing.Size(80, 23);
			this.orgTypeLabel.TabIndex = 3;
			this.orgTypeLabel.Text = "Chart Type";
			this.orgTypeLabel.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// orgCatLabel
			// 
			this.orgCatLabel.Location = new System.Drawing.Point(8, 72);
			this.orgCatLabel.Name = "orgCatLabel";
			this.orgCatLabel.Size = new System.Drawing.Size(80, 23);
			this.orgCatLabel.TabIndex = 2;
			this.orgCatLabel.Text = "Organized By";
			this.orgCatLabel.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// orgStatLabel
			// 
			this.orgStatLabel.Location = new System.Drawing.Point(8, 48);
			this.orgStatLabel.Name = "orgStatLabel";
			this.orgStatLabel.Size = new System.Drawing.Size(80, 23);
			this.orgStatLabel.TabIndex = 1;
			this.orgStatLabel.Text = "Stat";
			this.orgStatLabel.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// orgPlayerLabel
			// 
			this.orgPlayerLabel.Location = new System.Drawing.Point(8, 24);
			this.orgPlayerLabel.Name = "orgPlayerLabel";
			this.orgPlayerLabel.Size = new System.Drawing.Size(80, 24);
			this.orgPlayerLabel.TabIndex = 0;
			this.orgPlayerLabel.Text = "Player";
			this.orgPlayerLabel.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// singleGroupBox
			// 
			this.singleGroupBox.Controls.AddRange(new System.Windows.Forms.Control[] {
																						 this.singleTypeComboBox,
																						 this.singleTypeLabel,
																						 this.singleStatLabel,
																						 this.singleChartButton,
																						 this.singleStatComboBox,
																						 this.single3dCheckBox});
			this.singleGroupBox.Location = new System.Drawing.Point(8, 8);
			this.singleGroupBox.Name = "singleGroupBox";
			this.singleGroupBox.Size = new System.Drawing.Size(208, 112);
			this.singleGroupBox.TabIndex = 0;
			this.singleGroupBox.TabStop = false;
			this.singleGroupBox.Text = "Single Stat Charts";
			// 
			// singleTypeComboBox
			// 
			this.singleTypeComboBox.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.singleTypeComboBox.Items.AddRange(new object[] {
																	"Bar",
																	"Pie"});
			this.singleTypeComboBox.Location = new System.Drawing.Point(104, 48);
			this.singleTypeComboBox.Name = "singleTypeComboBox";
			this.singleTypeComboBox.Size = new System.Drawing.Size(96, 21);
			this.singleTypeComboBox.TabIndex = 4;
			// 
			// singleTypeLabel
			// 
			this.singleTypeLabel.Location = new System.Drawing.Point(8, 48);
			this.singleTypeLabel.Name = "singleTypeLabel";
			this.singleTypeLabel.Size = new System.Drawing.Size(88, 24);
			this.singleTypeLabel.TabIndex = 3;
			this.singleTypeLabel.Text = "Chart Type";
			this.singleTypeLabel.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// singleStatLabel
			// 
			this.singleStatLabel.Location = new System.Drawing.Point(8, 24);
			this.singleStatLabel.Name = "singleStatLabel";
			this.singleStatLabel.Size = new System.Drawing.Size(88, 24);
			this.singleStatLabel.TabIndex = 2;
			this.singleStatLabel.Text = "Stat";
			this.singleStatLabel.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// singleChartButton
			// 
			this.singleChartButton.Location = new System.Drawing.Point(128, 80);
			this.singleChartButton.Name = "singleChartButton";
			this.singleChartButton.Size = new System.Drawing.Size(72, 24);
			this.singleChartButton.TabIndex = 1;
			this.singleChartButton.Text = "Show Chart";
			// 
			// singleStatComboBox
			// 
			this.singleStatComboBox.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.singleStatComboBox.Items.AddRange(new object[] {
																	"Score",
																	"Kills",
																	"Deaths",
																	"Assists",
																	"Games",
																	"Avg Score",
																	"Avg Kills",
																	"Avg Deaths",
																	"Avg Assists"});
			this.singleStatComboBox.Location = new System.Drawing.Point(104, 24);
			this.singleStatComboBox.Name = "singleStatComboBox";
			this.singleStatComboBox.Size = new System.Drawing.Size(96, 21);
			this.singleStatComboBox.TabIndex = 0;
			// 
			// single3dCheckBox
			// 
			this.single3dCheckBox.Location = new System.Drawing.Point(80, 80);
			this.single3dCheckBox.Name = "single3dCheckBox";
			this.single3dCheckBox.Size = new System.Drawing.Size(40, 24);
			this.single3dCheckBox.TabIndex = 2;
			this.single3dCheckBox.Text = "3D";
			// 
			// saveMenuItem
			// 
			this.saveMenuItem.Index = 0;
			this.saveMenuItem.Shortcut = System.Windows.Forms.Shortcut.CtrlS;
			this.saveMenuItem.Text = "Save Stats...";
			// 
			// openMenuItem
			// 
			this.openMenuItem.Index = 1;
			this.openMenuItem.Shortcut = System.Windows.Forms.Shortcut.CtrlO;
			this.openMenuItem.Text = "Open Stats...";
			// 
			// separator2MenuItem
			// 
			this.separator2MenuItem.Index = 2;
			this.separator2MenuItem.Text = "-";
			// 
			// HSCForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(448, 273);
			this.Controls.AddRange(new System.Windows.Forms.Control[] {
																		  this.contentPanel,
																		  this.statusBar});
			this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
			this.Menu = this.hscFormMenu;
			this.Name = "HSCForm";
			this.SizeGripStyle = System.Windows.Forms.SizeGripStyle.Show;
			this.StartPosition = System.Windows.Forms.FormStartPosition.Manual;
			this.Text = "Halo2 Stat Collector";
			((System.ComponentModel.ISupportInitialize)(this.textStatusPanel)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.progStatusPanel)).EndInit();
			this.contentPanel.ResumeLayout(false);
			this.hscTabPane.ResumeLayout(false);
			this.overviewTab.ResumeLayout(false);
			this.averagesTab.ResumeLayout(false);
			this.viewerTab.ResumeLayout(false);
			this.chartsTab.ResumeLayout(false);
			this.otherGroupBox.ResumeLayout(false);
			this.orgGroupBox.ResumeLayout(false);
			this.singleGroupBox.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion

	}
}
