using System;
using System.Drawing;
using System.Windows.Forms;

using hsc.system;

namespace hsc.presentation
{
	/// <summary>
	/// Listens for events from menu items and takes appropriate action.
	/// </summary>
	public class HSCFormMenuListener
	{
		/// <summary>
		/// Creates a new HSCFormMenuListener.
		/// </summary>
		public HSCFormMenuListener()
		{
		}

		/// <summary>
		/// Called when the add player menu item is clicked.
		/// </summary>
		/// <param name="source">The event's source.</param>
		/// <param name="e">The event's data.</param>
		public void addPlayerItemClicked( Object source, EventArgs e )
		{
			AddPlayerDialog dialog = new AddPlayerDialog();
			DialogResult retVal = dialog.ShowDialog( HSCMain.HscForm );

			if ( retVal != DialogResult.OK )
			{
				return;
			}

			String rssLink = dialog.RSSLinkText;
			String playerName = dialog.NameText;

			if ( playerName.Equals( "" ) )
			{
				MessageBox.Show( HSCMain.HscForm, "Please enter a player name.", "Error",
					MessageBoxButtons.OK, MessageBoxIcon.Error );
				addPlayerItemClicked( source, e );
				return;
			}
			
			if ( rssLink.Equals( "" ) )
			{
				MessageBox.Show( HSCMain.HscForm, "Make sure to copy and paste your Halo2RSS link.", "Error",
					MessageBoxButtons.OK, MessageBoxIcon.Error );
				addPlayerItemClicked( source, e );
				return;
			}

			HSCPlayers.Instance.addPlayer( playerName, rssLink );

			HSCMain.HscForm.updateStats();
		}

		/// <summary>
		/// Called when the clear archived stats menu item is clicked.
		/// </summary>
		/// <param name="source">The event's source.</param>
		/// <param name="e">The event's data.</param>
		public void clearStatsItemClicked( Object source, EventArgs e )
		{
			SelectPlayersDialog dialog = new SelectPlayersDialog();
			dialog.Text = "Clear Player(s) Stats";
			dialog.GroupBoxText = "Select player(s) to clear stats";
			DialogResult retVal = dialog.ShowDialog( HSCMain.HscForm );

			if ( retVal != DialogResult.OK )
			{
				return;
			}

            retVal = MessageBox.Show( HSCMain.HscForm, dialog.PlayerListBox.CheckedItems.Count +
                " player's stats will be cleared.  Continue?", "Continue?",
                MessageBoxButtons.YesNo, MessageBoxIcon.Question );

            if ( retVal != DialogResult.Yes )
            {
                return;
            }

			HSCPlayers players = HSCPlayers.Instance;

			foreach ( String name in dialog.PlayerListBox.CheckedItems )
			{
				players[name].clearArchivedStats();
			}

			HSCMain.HscForm.updateStats();
		}

		/// <summary>
		/// Called when the exit menu item is clicked.
		/// </summary>
		/// <param name="source">The event's source.</param>
		/// <param name="e">The event's data.</param>
		public void exitItemClicked( Object source, EventArgs e )
		{
			HSCMain.HscForm.Close();
		}

		/// <summary>
		/// Called when the open stat archive menu item is clicked.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		public void openArchiveItemClicked( Object source, EventArgs e )
		{
			Properties props = Properties.Instance;

			OpenFileDialog fileChooser = new OpenFileDialog();
			fileChooser.DefaultExt = "hsa";
			fileChooser.Filter = "HSC Stat Archives (*.hsa)|*.hsa";
			fileChooser.InitialDirectory = props.getProperty( "lastopenstats.dir", "" );
			fileChooser.Title = "Open HSC Stat Archive";

			fileChooser.ShowDialog( HSCMain.HscForm );

			String filePath = fileChooser.FileName;
			if ( !( filePath.Equals( "" ) ) )
			{
				HSCPlayers.Instance.openStatArchive( filePath );

				props.setProperty( "lastopenstats.dir", fileChooser.InitialDirectory );
				HSCMain.HscForm.StatusBarText = "Opened Stat Archive: " + filePath;

				HSCMain.HscForm.updateStats();
			}
		}

		/// <summary>
		/// Called when the remove player menu item is clicked.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		public void removePlayerItemClicked( Object source, EventArgs e )
		{
			SelectPlayersDialog dialog = new SelectPlayersDialog();
			dialog.Text = "Remove Player(s)";
			dialog.GroupBoxText = "Select player(s) to remove";
			DialogResult retVal = dialog.ShowDialog( HSCMain.HscForm );

			if ( retVal != DialogResult.OK )
			{
				return;
			}

            retVal = MessageBox.Show( HSCMain.HscForm, dialog.PlayerListBox.CheckedItems.Count +
                " player(s) will be removed.  Continue?", "Continue?",
                MessageBoxButtons.YesNo, MessageBoxIcon.Question );

            if ( retVal != DialogResult.Yes )
            {
                return;
            }

			HSCPlayers players = HSCPlayers.Instance;

			foreach ( String name in dialog.PlayerListBox.CheckedItems )
			{
				players.removePlayer( name );
			}

			HSCMain.HscForm.updateView();
		}

		/// <summary>
		/// Called when the save stat archive menu item is clicked.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		public void saveArchiveItemClicked( Object source, EventArgs e )
		{
			Properties props = Properties.Instance;

			SaveFileDialog fileChooser = new SaveFileDialog();
			fileChooser.AddExtension = true;
			fileChooser.DefaultExt = "hsa";
			fileChooser.Filter = "HSC Stat Archives (*.hsa)|*.hsa|All Files|*.*";
			fileChooser.InitialDirectory = props.getProperty( "lastsavestats.dir", "" );
			fileChooser.OverwritePrompt = true;
			fileChooser.Title = "Save HSC Stat Archive";

			fileChooser.ShowDialog( HSCMain.HscForm );

			String filePath = fileChooser.FileName;
			if ( !( filePath.Equals( "" ) ) )
			{
				HSCPlayers.Instance.saveStatArchive( filePath );

				props.setProperty( "lastsavestats.dir", fileChooser.InitialDirectory );				
				HSCMain.HscForm.StatusBarText = "Saved Stat Archive: " + filePath;
			}
		}

		/// <summary>
		/// Called when the update stats menu item is clicked.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		public void updateItemClicked( Object source, EventArgs e )
		{
			HSCMain.HscForm.updateStats();
		}
	}
}
