using System;
using System.Collections;
using System.IO;
using System.Net;
using System.Text;
using System.Text.RegularExpressions;
using System.Windows.Forms;
using System.Xml;

namespace hsc.system
{
	/// <summary>
	/// Represents an HSC player.
	/// </summary>
	[Serializable]
	public class HSCPlayer
	{
		private String name;
		private String gamerTag;
		private String rssLink;
		private String pubDate;
		private ArrayList gameInfoList;

		/// <summary>Gets the player's average number of assists.</summary>
		/// <value>A float.</value>
		public float AvgAssists
		{
			get
			{
				return ( (float)TotalAssists / (float)gameInfoList.Count );
			}
		}

		/// <summary>Gets the player's average number of deaths.</summary>
		/// <value>A float.</value>
		public float AvgDeaths
		{
			get
			{
				return ( (float)TotalDeaths / (float)gameInfoList.Count );
			}
		}

		/// <summary>Gets the player's average number of kills.</summary>
		/// <value>A float.</value>
		public float AvgKills
		{
			get
			{
				return ( (float)TotalKills / (float)gameInfoList.Count );
			}
		}

		/// <summary>Gets the player's average number of kills
		/// above or below the .500 kills/deaths ratio.</summary>
		/// <value>A float.</value>
		public float AvgPlusMinus
		{
			get
			{
				return ( ( (float)TotalKills - (float)TotalDeaths ) / (float)gameInfoList.Count );
			}
		}

		/// <summary>Gets the player's average score.</summary>
		/// <value>A float.</value>
		public float AvgScore
		{
			get
			{
				return ( (float)TotalScore / (float)gameInfoList.Count );
			}
		}

		/// <summary>Gets this player's gameinfo list.</summary>
		/// <value>A List.</value>
		public IList GameInfos
		{
			get
			{
				return gameInfoList;
			}
		}

		/// <summary>Gets or sets the player's gamertag.</summary>
		/// <value>A String.</value>
		public String GamerTag
		{
			get
			{
				return gamerTag;
			}

			set
			{
				gamerTag = value;
			}
		}

		/// <summary>Gets or sets the player's name.</summary>
		/// <value>A string.</value>
		public String Name
		{
			get
			{
				return name;
			}

			set
			{
				name = value;
			}
		}

		/// <summary>Gets or sets the stats published date.</summary>
		/// <value>A String.</value>
		public DateTime PubDate
		{
			get
			{
				return DateTime.Parse( pubDate );
			}
			
			set
			{
				pubDate = value.ToString();
			}
		}

        /// <summary>Gets the player's RoboRanking (tm)</summary>
        /// <value>An float.</value>
        public float RoboRank
        {
            get
            {
                return computeRoboRank();
            }
        }

		/// <summary>Gets or sets the player's Halo2RSS link.</summary>
		/// <value>A string.</value>
		public String RSSLink
		{
			get
			{
				return rssLink;
			}

			set
			{
				rssLink = value;
			}
		}

		/// <summary>Gets the player's total number of assists.</summary>
		/// <value>An int.</value>
		public int TotalAssists
		{
			get
			{
				int retVal = 0;
				foreach ( GameInfo info in gameInfoList )
				{
					retVal += info.Assists;
				}
				return retVal;
			}
		}

		/// <summary>Gets the player's total number of deaths.</summary>
		/// <value>An int.</value>
		public int TotalDeaths
		{
			get
			{
				int retVal = 0;
				foreach ( GameInfo info in gameInfoList )
				{
					retVal += info.Deaths;
				}
				return retVal;
			}
		}

		/// <summary>Gets the player's total number of kills.</summary>
		/// <value>An int.</value>
		public int TotalKills
		{
			get
			{
				int retVal = 0;
				foreach ( GameInfo info in gameInfoList )
				{
					retVal += info.Kills;
				}
				return retVal;
			}
		}

		/// <summary>Gets the player's total score.</summary>
		/// <value>An int.</value>
		public int TotalScore
		{
			get
			{
				int retVal = 0;
				foreach ( GameInfo info in gameInfoList )
				{
					retVal += info.Score;
				}
				return retVal;
			}
		}

		/// <summary>
		/// Creates a new HSCPlayer.
		/// </summary>
		public HSCPlayer() :
			this( null, null )
		{
		}

		/// <summary>
		/// Creates a new player with the specified information.
		/// </summary>
		/// <param name="name">The player's name.</param>
		/// <param name="rssLink">The player's Halo2RSS link</param>
		public HSCPlayer( String name, String rssLink )
		{
			this.Name = name;
			this.RSSLink = rssLink;

			gameInfoList = new ArrayList();
		}

		/// <summary>
		/// Clears this player's archived stats.
		/// </summary>
		public void clearArchivedStats()
		{
			gameInfoList.Clear();
		}

		/// <summary>
		/// Reads the player's stats from the RSS feed.
		/// </summary>
		public void compileStats()
		{
			HttpWebRequest request = (HttpWebRequest)WebRequest.Create( rssLink );
			HttpWebResponse response = (HttpWebResponse)request.GetResponse();

			XmlTextReader rssReader = null;

			try
			{
				StreamReader stream =
					new StreamReader( response.GetResponseStream(), Encoding.UTF8 );
				rssReader = new XmlTextReader( stream );
			}
			catch ( Exception )
			{
				rssReader = null;
			}

			if ( rssReader == null )
			{
				MessageBox.Show( HSCMain.HscForm, "Error getting stats, try again later.",
					"Error", MessageBoxButtons.OK, MessageBoxIcon.Error );
				return;
			}

			try
			{
				while ( rssReader.Read() )
				{
					if ( rssReader.Name.Equals( "channel" ) &&
						rssReader.NodeType != XmlNodeType.EndElement )
					{
						parseChannelInfo( rssReader );
					}
					else if ( rssReader.Name.Equals( "item" ) &&
						rssReader.NodeType != XmlNodeType.EndElement )
					{
						parseGameInfo( rssReader );
					}
				}
			}
			catch ( Exception e )
			{
				MessageBox.Show( HSCMain.HscForm, "Error while reading stats: " + e.Message,
					"Error", MessageBoxButtons.OK, MessageBoxIcon.Error );
			}
			finally
			{
				if ( rssReader != null )
				{
					rssReader.Close();
				}
			}
		}

        /// <summary>
        /// Computes this player's RoboRank (tm).
        /// </summary>
        /// <returns>The player's current RoboRank (tm).</returns>
        private float computeRoboRank()
        {
            ArrayList playerList = new ArrayList( HSCPlayers.Instance.Players );

            playerList.Sort(
                new RoboRankComparer( RoboRankComparer.COMPARE_AVG_ASSISTS ) );
            int assistsRank = Math.Abs(
                ( playerList.IndexOf( this ) + 1 ) - playerList.Count );

            playerList.Sort(
                new RoboRankComparer( RoboRankComparer.COMPARE_AVG_KILLS ) );
            int killsRank = Math.Abs(
                ( playerList.IndexOf( this ) + 1 ) - playerList.Count );

            playerList.Sort(
                new RoboRankComparer( RoboRankComparer.COMPARE_AVG_DEATHS ) );
            int deathsRank = playerList.IndexOf( this );

            return ( ( assistsRank * 0.5F ) + killsRank + deathsRank );
        }

		/// <summary>
		/// Tells whether the given GameInfo is already in the list of previously archived GameInfos.
		/// </summary>
		/// <param name="gInfo">The GmaeInfo in question.</param>
		/// <returns>True if the GameInfo has already been archived, false otherwise.</returns>
		private bool alreadyArchived( GameInfo gInfo )
		{
			bool retVal = false;

			foreach ( GameInfo info in gameInfoList )
			{
				if ( info.GameLink.Equals( gInfo.GameLink ) )
				{
					retVal = true;
					break;
				}
			}

			return retVal;
		}

		/// <summary>
		/// Collects channel header information.
		/// </summary>
		/// <param name="rssReader">The reader to use.</param>
		private void parseChannelInfo( XmlTextReader rssReader )
		{
			while ( !rssReader.Name.Equals( "title" ) )
			{
				rssReader.Read();
			}
			rssReader.Read();
			String title = rssReader.Value;
			gamerTag = title.Substring( 0, title.IndexOf( "'s recent" ) );

			while ( !rssReader.Name.Equals( "pubDate" ) )
			{
				rssReader.Read();
			}
			rssReader.Read();
			pubDate = rssReader.Value;
		}

		/// <summary>
		/// Collects information about a game.
		/// </summary>
		/// <param name="rssReader">The reader to use.</param>
		private void parseGameInfo( XmlTextReader rssReader )
		{
			GameInfo gInfo = new GameInfo();

			while ( !rssReader.Name.Equals( "title" ) )
			{
				rssReader.Read();
			}
			rssReader.Read();
			gInfo.Level = rssReader.Value.Substring( rssReader.Value.IndexOf( "on " ) + 3 );
			HSCMain.HscForm.StatusBarText = "Getting " + name + "'s Stats for: " + gInfo.Level;

			while ( !rssReader.Name.Equals( "link" ) )
			{
				rssReader.Read();
			}
			rssReader.Read();
			gInfo.GameLink = rssReader.Value;

			if ( alreadyArchived( gInfo ) )
			{
				return;
			}

			while ( !rssReader.Name.Equals( "pubDate" ) )
			{
				rssReader.Read();
			}
			rssReader.Read();
			gInfo.PlayDate = DateTime.Parse( rssReader.Value );

			while ( !rssReader.Name.Equals( "description" ) )
			{
				rssReader.Read();
			}
			rssReader.Read();

			Regex regEx = new Regex( "(<br/>)" );
			String[] fields = regEx.Split( rssReader.Value );

			foreach ( String field in fields )
			{
				if ( field.StartsWith( "Playlist" ) )
				{
					gInfo.PlayList = field.Substring( field.IndexOf( ": " ) + 2 );
				}
				else if ( field.StartsWith( gamerTag ) )
				{
					String statLine = field.Substring( field.IndexOf( ": " ) + 2 );
					String playerPart = field.Substring( 0, field.IndexOf( statLine ) );

					int index1 = playerPart.LastIndexOf( "(" ) + 1;
					int index2 = playerPart.LastIndexOf( ")" );

                    if ( index1 == 0 && index2 == -1 )
                    {
                        gInfo.TeamName = "Self";
                    }
                    else
                    {
                        gInfo.TeamName = playerPart.Substring( index1, index2 - index1 );
                    }

					String[] statFields = statLine.Split( ',' );

					if ( statFields.Length == 5 )
					{
                        String standing = statFields[0];
                        standing = standing.Substring( 0, standing.Length - 2 );

                        gInfo.PlayerPlace = Int32.Parse(
                            statFields[0].Substring( 0, statFields[0].Length - 2 ) );
						gInfo.Score = Int32.Parse( statFields[1].Trim() );
						gInfo.Kills = Int32.Parse( statFields[2].Trim() );
						gInfo.Deaths = Int32.Parse( statFields[3].Trim() );
						gInfo.Assists = Int32.Parse( statFields[4].Trim() );
					}
				}
			}

			gameInfoList.Add( gInfo );
		}
	}
}
