using System;
using System.Collections;
using System.IO;
using System.Runtime.Serialization;
using System.Runtime.Serialization.Formatters.Soap;
using System.Windows.Forms;

namespace hsc.system
{
	/// <summary>
	/// Keeps track of HSC players.
	/// </summary>
	public class HSCPlayers
	{
		protected static HSCPlayers instance = new HSCPlayers();

		private String archiveFilePath;
		private Hashtable namesToPlayers;

		/// <summary>Gets the system-wide HSCPlayers object.</summary>
		/// <value>An HSCPlayers object.</value>
		public static HSCPlayers Instance
		{
			get
			{
				return instance;
			}
		}

		/// <summary>Gets the current stat archive file path.</summary>
		/// <value>A String.</value>
		public String CurrentArchivePath
		{
			get
			{
				return archiveFilePath;
			}
		}

		/// <summary>Gets a list of all HSC players.</summary>
		/// <value>An ICollection.</value>
		public ICollection Players
		{
			get
			{
				return new ArrayList( namesToPlayers.Values );
			}
		}

		/// <summary>Gets the HSC player with the specified name.</summary>
		/// <value>An HSCPlayer.</value>
		public HSCPlayer this[String name]
		{
			get
			{
				return (HSCPlayer)namesToPlayers[name];
			}
		}

		/// <summary>
		/// Clients do not instantiate HSCPlayers.
		/// </summary>
		protected HSCPlayers()
		{
			Properties props = Properties.Instance;
			archiveFilePath = props.getProperty( "lastarchive.path", "" );

			try
			{
				readStatArchive( archiveFilePath );
			}
			catch ( Exception )
			{
                props.setProperty( "lastarchive.path", "" );
                archiveFilePath = "";
				namesToPlayers = new Hashtable();
			}
		}

		/// <summary>
		/// Adds a HSC player.
		/// </summary>
		/// <param name="name">The player's unique name.</param>
		/// <param name="rssLink">The player's Halo2RSS link.</param>
		public void addPlayer( String name, String rssLink )
		{
			HSCPlayer p = new HSCPlayer( name, rssLink );
			namesToPlayers[name] = p;
		}

		/// <summary>
		/// Gets the HSC player with the specified name.
		/// </summary>
		/// <param name="name">The player's name.</param>
		/// <returns>The HSC player, or null if no player has the given name.</returns>
		public HSCPlayer getPlayer( String name )
		{
			return (HSCPlayer)namesToPlayers[name];
		}

		/// <summary>
		/// Opens an HSC stat archive file named by the given file path.
		/// </summary>
		/// <param name="filePath">The path to the desired file.</param>
		public void openStatArchive( String filePath )
		{
			try
			{
				readStatArchive( filePath );

				archiveFilePath = filePath;
			}
			catch ( Exception e )
			{
				MessageBox.Show( HSCMain.HscForm,
					"Error opening stats: " + e.Message, "Error",
					MessageBoxButtons.OK, MessageBoxIcon.Error );
			}
		}

		/// <summary>
		/// Removes a HSC player from the system.  Does nothing if no player with
		/// the given name was found.
		/// </summary>
		/// <param name="name">The name of the player to remove.</param>
		public void removePlayer( String name )
		{
			namesToPlayers.Remove( name );
		}

		/// <summary>
		/// Writes a HSC stat archive file named by the specified file path.
		/// </summary>
		/// <param name="filePath">The desired file path.</param>
		public void saveStatArchive( String filePath )
		{
			try
			{
				writeStatArchive( filePath );
			}
			catch ( Exception e )
			{
				MessageBox.Show( HSCMain.HscForm,
					"Error saving stats: " + e.Message, "Error",
					MessageBoxButtons.OK, MessageBoxIcon.Error );
			}
		}

		/// <summary>
		/// Reads a HSC stat archive file from the given file path.
		/// </summary>
		/// <param name="filePath">The desired file path.</param>
		private void readStatArchive( String filePath )
		{
			IFormatter formatter = new SoapFormatter();
			FileStream playerInput = new FileStream(
				filePath, FileMode.Open, FileAccess.Read, FileShare.Read );
				
			namesToPlayers = (Hashtable)formatter.Deserialize( playerInput );
				
			playerInput.Close();
		}

		/// <summary>
		/// Writes a HSC stat archive file to the given file path.
		/// </summary>
		/// <param name="filePath">The desired file path to write.</param>
		private void writeStatArchive( String filePath )
		{
			IFormatter formatter = new SoapFormatter();
			FileStream playerOutput = new FileStream(
				filePath, FileMode.Create, FileAccess.Write, FileShare.None );
				
			formatter.Serialize( playerOutput, namesToPlayers );
				
			playerOutput.Close();
		}
	}
}
