using System;
using System.IO;
using System.Text;
using System.Collections;
using System.Reflection;
using System.Runtime.Serialization;
using System.Runtime.Serialization.Formatters.Soap;

namespace hsc.system
{
	/// <summary>
	/// Manages setting and getting of system-wide properties and configuration.
	/// </summary>
	public class Properties
	{
		private static Properties instance = null;

		private String propFilePath = "./conf/props.tbl";
		private Hashtable props = new Hashtable();

		/// <summary>Gets the singleton instance of JVMSProperties</summary>
		/// <value>The singleton instance of JVMSProperties.</value>
		public static Properties Instance
		{
			get
			{
				if ( instance == null )
				{
					instance = new Properties();
				}
				return instance;
			}
		}
        
		/// <summary>
		/// Creates a new Properties.
		/// </summary>
		private Properties()
		{
			try
			{
				initProperties();
				readProps();
			}
			catch ( SerializationException e )
			{
				Console.Error.WriteLine( "Error reading properties file: " + propFilePath );
				Console.Error.WriteLine( e.StackTrace );
			}
			catch ( FileNotFoundException )
			{
				Console.Error.WriteLine( "Could not find properties file: " + propFilePath );
				Console.Error.WriteLine( "A new properties file will be created at this location." );
			}
		}

		/// <summary>
		/// Returns the property with the given name or a default value if no property exists.
		/// </summary>
		/// <param name="key">The name of the desired property.</param>
		/// <param name="def">A default value.</param>
		/// <returns>The desired property or a default value.</returns>
		public String getProperty( String key, String def )
		{
			if ( props.Contains( key ) )
			{
				return props[key].ToString();
			}
			else
			{
				return def;
			}
		}

		/// <summary>
		/// Returns the property with the given name or a default value if no property exists.
		/// </summary>
		/// <param name="key">The name of the desired property.</param>
		/// <param name="def">A default value.</param>
		/// <returns>The desired property or a default value.</returns>
		public int getProperty( String key, int def )
		{
			if ( props.Contains( key ) )
			{
				try
				{
					return Int32.Parse( props[key].ToString() );
				}
				catch ( Exception )
				{
					return def;
				}
			}
			else
			{
				return def;
			}
		}

		/// <summary>
		/// Returns the property with the given name or a default value if no property exists.
		/// </summary>
		/// <param name="key">The name of the desired property.</param>
		/// <param name="def">A default value.</param>
		/// <returns>The desired property, or the default value.</returns>
		public Object getProperty( String key, Object def )
		{
			if ( props.Contains( key ) )
			{
				return props[key];
			}
			else
			{
				return def;
			}
		}

		/// <summary>
		/// Gets a list of available property keys.
		/// </summary>
		/// <returns></returns>
		public ICollection getPropertyKeys()
		{
			return props.Keys;
		}

		/// <summary>
		/// Sets the specified property to the given value
		/// </summary>
		/// <param name="key">The name of the property.</param>
		/// <param name="value">The property value.</param>
		public void setProperty( String key, Object value )
		{
			props[key] = value;
		}

		/// <summary>
		/// Writes the current properties to a file.
		/// </summary>
		/// <exception cref="SerializationException">If there was an error writing the properties.</exception>
		public void writeProps()
		{
			try
			{
				IFormatter formatter = new SoapFormatter();
				FileStream propOut = new FileStream( propFilePath, FileMode.Create,
					FileAccess.Write, FileShare.None );
				formatter.Serialize( propOut, props );
				propOut.Close();
			}
			catch ( Exception e )
			{
				Console.WriteLine( "Error writing properties: " + propFilePath );
				Console.WriteLine( e.Message );
				Console.WriteLine( e.StackTrace );
			}
		}

		/// <summary>
		/// Reads properties that have been persisted to a file.
		/// </summary>
		/// <exception cref="SerializationException">If there was an error reading the properties.</exception>
		/// <exception cref="FileNotFoundException">If the properties file could not be found.</exception>
		public void readProps()
		{
			try
			{
				IFormatter formatter = new SoapFormatter();
				FileStream propIn = new FileStream( propFilePath, FileMode.Open,
					FileAccess.Read, FileShare.Read );
				props = (Hashtable)formatter.Deserialize( propIn );
				propIn.Close();
			}
			catch ( Exception e )
			{
				Console.WriteLine( "Error reading properties: " + propFilePath );
				Console.WriteLine( e.Message );
				Console.WriteLine( e.StackTrace );
			}
		}

		/// <summary>
		/// Initializes properties to their last persisted state.
		/// </summary>
		/// <exception cref="FileNotFoundException">If the system initialization file could not be found.</exception>
		private void initProperties()
		{
			try
			{
				Assembly hscAssembly = Assembly.GetExecutingAssembly();
				String assemblyLocation = hscAssembly.Location.Substring( 0, hscAssembly.Location.LastIndexOf( '\\' ) + 1 );
				FileStream fin = File.Open( assemblyLocation + "boot.ini", FileMode.Open );

				byte[] buf = new byte[fin.Length];
				fin.Read( buf, 0, buf.Length );
				String fileData = Encoding.ASCII.GetString( buf );
    
				String[] lines = fileData.Split( '\n' );
				foreach ( String l in lines )
				{
					String line = l.Trim();
					if ( !( line.StartsWith( "#" ) || line.Equals( "" ) ) )
					{
						propFilePath = assemblyLocation + line;
					}
				}
			}
			catch ( FileNotFoundException e )
			{
				Console.Error.WriteLine( "Could not find system initialization file: boot.ini" );
				Console.Error.WriteLine( e.StackTrace );
				Environment.Exit( -1 );
			}
		}
	}
}
