using System;
using System.Collections;
using System.Windows.Forms;

namespace hsc.system
{
	/// <summary>
	/// Compares HSC player stat values, for purposes of sorting.
	/// </summary>
	public class StatComparer : IComparer
	{
		public const int SORT_ASCENDING = 0;
		public const int SORT_DESCENDING = 1;

		public const int TYPE_STRING = 10;
		public const int TYPE_INTEGER = 11;
		public const int TYPE_FLOAT = 12;

		private int sortCol;
		private int sortDir;
		private int sortType;

		/// <summary>Gets the sort column.</summary>
		/// <value>An int.</value>
		public int SortColumn
		{
			get
			{
				return sortCol;
			}
		}

		/// <summary>Gets the sort direction.</summary>
		/// <value>An int.</value>
		public int SortDirection
		{
			get
			{
				return sortDir;
			}
		}

		/// <summary>
		/// Creates a new StatComparer with the given sorting
		/// stat column and sort direction.
		/// </summary>
		/// <param name="col">The stat column to sort</param>
		/// <param name="sort">The direction to sort, must be either
		/// SORT_ASCENDING or SORT_DESCENDING.</param>
		/// <param name="type">The type of data being sorted, must
		/// be one of the TYPE_* constants.</param>
		public StatComparer( int col, int direction, int type )
		{
			if ( direction != SORT_ASCENDING && direction != SORT_DESCENDING )
			{
				throw new ArgumentException( "Invalid sort direction." );
			}

			if ( type != TYPE_STRING && type != TYPE_INTEGER && type != TYPE_FLOAT )
			{
				throw new ArgumentException( "Invalid sort type." );
			}

			sortCol = col;
			sortDir = direction;
			sortType = type;
		}

		/// <summary>
		/// Compares two objects.
		/// </summary>
		/// <param name="x">The first object.</param>
		/// <param name="y">The second object.</param>
		/// <returns>Less and zero if x less than y, zero if z equals y,
		/// greater than zero if x is greater than y.</returns>
		public int Compare( Object x, Object y )
		{
			if ( !( x is ListViewItem && y is ListViewItem ) )
			{
				throw new ArgumentException( "x and y must be ListViewItems." );
			}

			ListViewItem item1 = (ListViewItem)x;
			ListViewItem item2 = (ListViewItem)y;
			int retVal = 0;

			String value1 = item1.SubItems[sortCol].Text;
			String value2 = item2.SubItems[sortCol].Text;

			if ( sortType == TYPE_STRING )
			{
				if ( sortDir == StatComparer.SORT_DESCENDING )
				{
					retVal = value1.CompareTo( value2 );
				}
				else if ( sortDir == StatComparer.SORT_ASCENDING )
				{
					retVal = value2.CompareTo( value1 );
				}
			}
			else if ( sortType == TYPE_INTEGER )
			{
				int intValue1 = Int32.Parse( value1 );
				int intValue2 = Int32.Parse( value2 );

				if ( sortDir == StatComparer.SORT_DESCENDING )
				{
					retVal = intValue2.CompareTo( intValue1 );
				}
				else if ( sortDir == StatComparer.SORT_ASCENDING )
				{
					retVal = intValue1.CompareTo( intValue2 );
				}
			}
			else if ( sortType == TYPE_FLOAT )
			{
				float fpValue1 = float.Parse( value1 );
				float fpValue2 = float.Parse( value2 );

				if ( sortDir == StatComparer.SORT_DESCENDING )
				{
					retVal = fpValue2.CompareTo( fpValue1 );
				}
				else if ( sortDir == StatComparer.SORT_ASCENDING )
				{
					retVal = fpValue1.CompareTo( fpValue2 );
				}
			}

			return retVal;
		}
	}
}
